@@ -10,6 +10,7 @@ from deployfish.core.utils import is_fnmatch_filter
 from .abstract import Manager, Model, LazyAttributeMixin
 from .alb import TargetGroup
 from .ec2 import Instance, AutoscalingGroup
+from .efs import EFSFileSystem
 from .elb import ClassicLoadBalancer
 from .events import EventScheduleRule
 from .mixins import TaskDefinitionFARGATEMixin, TagsMixin
@@ -505,13 +506,35 @@ class AbstractTaskManager(Manager):
         response = self.client.run_task(**obj.render())
         return [InvokedTask(data) for data in response['tasks']]
 
+    def enable_schedule(self, pk):
+        # hint: (str["{family}:{revision}","{family}","{task_definition_arn}"])
+        """
+        If the task has a scchedule and the schedule rule is disabled, enable the schedule rule.  Otherwise
+        do nothing.
+
+        :param obj pk: the task to enable
+        """
+        obj = self.get(pk)
+        obj.enable_schedule()
+
+    def disable_schedule(self, pk):
+        # hint: (str["{family}:{revision}","{family}","{task_definition_arn}"])
+        """
+        If the task has a scchedule and the schedule rule is enabled, disable the schedule rule.  Otherwise
+        do nothing.
+
+        :param obj pk: the task to disable
+        """
+        obj = self.get(pk)
+        obj.disable_schedule()
+
 
 class StandaloneTaskManager(AbstractTaskManager):
 
     task_type = 'standalone'
     # model is set after the StandaloneTask class definition, below
 
-    def list(self, scheduled_only=False, all_revisions=False, task_type='standalone', service_name=None, cluster_name=None, task_name=None):
+    def list(self, scheduled_only=False, all_revisions=False, task_type='standalone', service_name=None, cluster_name=None, task_name=None):  # noqa:E501
         # hint: (bool, bool, choice[standalone|service_helper|any], str["{service_pk:glob}"], str["{cluster_name:glob}"], str["{task_name:glob}"])
         """
         List all Tasks (StandaloneTasks and ServiceHelperTasks), filtering by various dimensions.
@@ -562,9 +585,10 @@ class StandaloneTaskManager(AbstractTaskManager):
             for task in tasks:
                 if service_name:
                     # the service tag is actually a service pk: {cluster_name}:{service_name}
-                    cluster, service = task.data['service'].split(':')
-                    if fnmatch.fnmatch(service, service_name):
-                        matched_tasks.append(task)
+                    if 'service' in task.data:
+                        cluster, service = task.data['service'].split(':')
+                        if fnmatch.fnmatch(service, service_name):
+                            matched_tasks.append(task)
                 if cluster_name and is_fnmatch_filter(cluster_name):
                     if fnmatch.fnmatch(task.data['cluster'], cluster_name):
                         matched_tasks.append(task)
@@ -679,7 +703,8 @@ class ServiceHelperTaskManager(AbstractTaskManager):
         List all the ServiceHelperTasks.  To do this accurately, we need to:
 
             * List all the services
-            * Look at the active task definition for the "deployfish:task-name" tags and collect the task definition arns
+            * Look at the active task definition for the "deployfish:task-name" tags and collect the task
+              definition arns
             * Build ServiceHelperTasks based on those arns and return them
 
         We need to do this instead of just listing all tasks with the tag 'deployfish:type' of 'service_helper' because
@@ -984,7 +1009,7 @@ class ServiceManager(Manager):
             except self.client.exceptions.ClusterNotFoundException:
                 raise Cluster.DoesNotExist('No cluster with name "{}" exists in AWS'.format(cluster))
         if service_name:
-            services = [arn for arn in services if fnmatch.fnmatch(arn.split('/')[1], service_name)]
+            services = [arn for arn in services if fnmatch.fnmatch(arn.rsplit('/')[1], service_name)]
         return self.get_many(services)
 
     def save(self, obj):
@@ -1030,10 +1055,10 @@ class ServiceManager(Manager):
             for task in obj.helper_tasks:
                 task.unschedule()
             # first scale to 0
+            service, cluster = self.__get_service_and_cluster_from_pk(obj.pk)
             if obj.data['desiredCount'] > 0:
                 self.scale(obj, 0)
                 waiter = self.get_waiter('services_stable')
-                service, cluster = self.__get_service_and_cluster_from_pk(obj.pk)
                 waiter.wait(cluster=cluster, services=[service])
             # Then delete the service
             self.client.delete_service(cluster=cluster, service=service)
@@ -1161,7 +1186,7 @@ class TaskDefinition(TagsMixin, TaskDefinitionFARGATEMixin, SecretsMixin, Model)
     @property
     def secrets_prefix(self):
         if self.secrets:
-            return list(self.secrets.values()[0].prefix)
+            return self.secrets.values()[0].prefix
         else:
             raise self.ImproperlyConfigured(
                 'Can\'t determine secrets prefix for TaskDefinition(pk="{}"): it has no secrets'.format(self.pk)
@@ -1223,6 +1248,12 @@ class TaskDefinition(TagsMixin, TaskDefinitionFARGATEMixin, SecretsMixin, Model)
         if 'compatibilities' in data:
             data['requiresCompatibilities'] = data['compatibilities']
             del data['compatibilities']
+        if 'volumes' in data:
+            for volume in data['volumes']:
+                if 'efsVolumeConfiguration' in volume:
+                    volume['efsVolumeConfiguration']['FileSystem'] = EFSFileSystem.objects.get(
+                        volume['efsVolumeConfiguration']['fileSystemId']
+                    )
         return data
 
     def render_for_diff(self):
@@ -1301,7 +1332,7 @@ class ContainerDefinition(SecretsMixin, LazyAttributeMixin):
     @property
     def secrets_prefix(self):
         if self.secrets:
-            return list(self.secrets.values()[0].prefix)
+            return self.secrets.values()[0].prefix
         else:
             raise self.ImproperlyConfigured(
                 'Can\'t determine secrets prefix for ContainerDefinition(pk="{}"): it has no secrets'.format(self.pk)
@@ -1368,8 +1399,8 @@ class Task(TagsMixin, Model):
         platformVersion: (optional) only used if launchType == FARGATE
         networkConfiguration.awsvpcConfiguration: If the task definition's networkMode is 'awsvpc', this tells us
             what subnets in which to run the tasks, and which security groups to assign to them
-        capacityProviderStrategy: (optional) the capacity provider strategy to use, if any.  This is mutually exclusive with
-            launchType
+        capacityProviderStrategy: (optional) the capacity provider strategy to use, if any.  This is mutually
+            exclusive with launchType
         placementConstraints: (optional) placement constraints for running the task
         placementStrategy: (optional) the placement strategy for running the task
         group: (optional)the task group
@@ -1463,6 +1494,14 @@ class Task(TagsMixin, Model):
         if self.schedule:
             self.schedule.delete()
 
+    def enable_schedule(self):
+        if self.schedule:
+            self.schedule.enable()
+
+    def disable_schedule(self):
+        if self.schedule:
+            self.schedule.disable()
+
     def render_for_display(self):
         data = deepcopy(self.data)
         if 'service' in self.data:
@@ -1470,10 +1509,11 @@ class Task(TagsMixin, Model):
         else:
             data['serviceName'] = ''
         data.update(self.task_definition.render_for_display())
+        data['schedule_expression'] = ''
+        data['schedule_disabled'] = ''
         if self.schedule:
             data['schedule_expression'] = self.schedule.data['ScheduleExpression']
-        else:
-            data['schedule_expression'] = ''
+            data['schedule_disabled'] = 'DISABLED' if not self.schedule.enabled else ''
         return data
 
 
@@ -1501,6 +1541,14 @@ class StandaloneTask(SecretsMixin, Task):
             self.cache['secrets'] = self.task_definition.secrets
         return self.cache['secrets']
 
+    def reload_secrets(self):
+        """
+        Reload our AWS SSM Paramter Store secrets from AWS.
+        """
+        super().reload_secrets()
+        self.task_definition.reload_secrets()
+
+
 # We need to set the manager model this way to avoid circular references
 StandaloneTaskManager.model = StandaloneTask  # noqa:E305
 
@@ -1719,7 +1767,9 @@ class Cluster(TagsMixin, SSHMixin, Model):
     @property
     def autoscaling_group(self):
         if 'autoscaling_group' not in self.cache:
-            if len(self.container_instances) > 0:
+            if 'deployfish:autoscalingGroup' in self.tags:
+                self.cache['autoscaling_group'] = AutoscalingGroup.objects.get(self.tags['deployfish:autoscalingGroup'])
+            elif len(self.container_instances) > 0:
                 self.cache['autoscaling_group'] = self.container_instances[0].autoscaling_group
             else:
                 # Try to guess our autoscaling group based on our cluster name
@@ -2024,7 +2074,8 @@ class Service(TagsMixin, DockerMixin, SecretsMixin, Model):
         data = {}
         data['service'] = self.data['serviceName']
         data['cluster'] = self.data['cluster']
-        data['desiredCount'] = self.data['desiredCount']
+        # Purposely not setting desiredCount here -- we may be scaled up, so we shouldn't be scaling back to whatever
+        # deployfish.yml says lest we underprovision the service inadvertently
         data['taskDefinition'] = self.data['taskDefinition']
         if 'capacityProviderStrategy' in self.data:
             data['capacityProviderStrategy'] = self.data['capacityProviderStrategy']
